@@ -29,10 +29,10 @@ from sklearn import svm
 import os, random, shutil
 
 class octid:
-    def __init__(self, model = 'googlenet',customised_model = False, feature_dimension = 3, outlier_fraction_of_SVM = 0.03, traning_dataset=None, validation_dataset=None, unlabeled_dataset=None):
+    def __init__(self, model = 'googlenet',customised_model = False, feature_dimension = 3, outlier_fraction_of_SVM = 0.03, training_dataset=None, validation_dataset=None, unlabeled_dataset=None):
         self.model_name = model
         self.dim = feature_dimension
-        self.templates_path = traning_dataset
+        self.templates_path = training_dataset
         self.val_path = validation_dataset
         self.unknown_path = unlabeled_dataset
         self.SVM_nu = outlier_fraction_of_SVM
